@@ -49,7 +49,7 @@ class CrawlerBase:
     def downloadSourceCodeAsBs4(self, url, proxy = None) -> Soup:
         """ Downloads the website and converts it to bs4 """
         r = self.downloadSourceCode(url=url, proxy=proxy)
-        return Soup(r.data, 'html.parser')
+        return Soup(r, 'html.parser')
 
     def waitForMultiprocessesToFinish(self, processes_to_await: List):
         """ Blocks until all the processes from the array are not finished """
